<?php

declare(strict_types=1);

namespace Drupal\whatsapp_formatter\Plugin\Field\FieldFormatter;

use Drupal\Core\Url;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Attribute\FieldFormatter;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\telephone\Plugin\Field\FieldFormatter\TelephoneLinkFormatter;

/**
 * Plugin implementation of the 'Whatsapp Number' formatter.
 */
#[FieldFormatter(
  id: 'whatsapp_number',
  label: new TranslatableMarkup('Whatsapp Number'),
  field_types: [
    'telephone',
  ],
)]
final class WhatsappNumberFormatter extends TelephoneLinkFormatter {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    // Keep the same logic as the core telephone number, only changing the URL.
    $element = parent::viewElements($items, $langcode);

    foreach ($items as $delta => $item) {
      $whatsapp_url = Url::fromUri("https://api.whatsapp.com/send", [
        'query' => [
          'phone' => $item->value,
        ],
      ]);
      $element[$delta]['#url'] = $whatsapp_url;
    }

    return $element;
  }

}
